# onelive-vgst
No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 0.1.1
- Package version: 0.1.1
- Generator version: 7.19.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.9+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import onelive_vgst
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import onelive_vgst
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import onelive_vgst
from onelive_vgst.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost
# See configuration.py for a list of all supported configuration parameters.
configuration = onelive_vgst.Configuration(
    host = "http://localhost"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure Bearer authorization: HTTPBearer
configuration = onelive_vgst.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)


# Enter a context with an instance of the API client
async with onelive_vgst.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = onelive_vgst.CustomersApi(api_client)
    customer_create = onelive_vgst.CustomerCreate() # CustomerCreate | 

    try:
        # Create Customer
        api_response = await api_instance.create_customer_customers_post(customer_create)
        print("The response of CustomersApi->create_customer_customers_post:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling CustomersApi->create_customer_customers_post: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*CustomersApi* | [**create_customer_customers_post**](docs/CustomersApi.md#create_customer_customers_post) | **POST** /customers | Create Customer
*CustomersApi* | [**delete_customer_customers_customer_id_delete**](docs/CustomersApi.md#delete_customer_customers_customer_id_delete) | **DELETE** /customers/{customer_id} | Delete Customer
*CustomersApi* | [**get_customer_customers_customer_id_get**](docs/CustomersApi.md#get_customer_customers_customer_id_get) | **GET** /customers/{customer_id} | Get Customer
*CustomersApi* | [**get_customers_customers_get**](docs/CustomersApi.md#get_customers_customers_get) | **GET** /customers | Get Customers
*CustomersApi* | [**get_me_customers_me_get**](docs/CustomersApi.md#get_me_customers_me_get) | **GET** /customers/me | Get Me
*CustomersApi* | [**update_customer_customers_customer_id_put**](docs/CustomersApi.md#update_customer_customers_customer_id_put) | **PUT** /customers/{customer_id} | Update Customer
*CustomersApi* | [**update_me_last_activity_customers_me_last_activity_post**](docs/CustomersApi.md#update_me_last_activity_customers_me_last_activity_post) | **POST** /customers/me/last-activity | Update Me Last Activity
*CustomersApi* | [**update_me_password_customers_me_update_post**](docs/CustomersApi.md#update_me_password_customers_me_update_post) | **POST** /customers/me/update | Update Me Password
*HealthApi* | [**get_health_status_health_check_get**](docs/HealthApi.md#get_health_status_health_check_get) | **GET** /health-check | Health check
*ProviderMatchesApi* | [**upsert_provider_matches_bulk_provider_matches_bulk_post**](docs/ProviderMatchesApi.md#upsert_provider_matches_bulk_provider_matches_bulk_post) | **POST** /provider-matches/bulk | Upsert Provider Matches Bulk
*ProvidersApi* | [**create_provider_providers_post**](docs/ProvidersApi.md#create_provider_providers_post) | **POST** /providers | Create Provider
*ProvidersApi* | [**delete_provider_providers_provider_id_delete**](docs/ProvidersApi.md#delete_provider_providers_provider_id_delete) | **DELETE** /providers/{provider_id} | Delete Provider
*ProvidersApi* | [**get_provider_providers_provider_id_get**](docs/ProvidersApi.md#get_provider_providers_provider_id_get) | **GET** /providers/{provider_id} | Get Provider
*ProvidersApi* | [**get_providers_providers_get**](docs/ProvidersApi.md#get_providers_providers_get) | **GET** /providers | Get Providers
*ProvidersApi* | [**update_provider_providers_provider_id_put**](docs/ProvidersApi.md#update_provider_providers_provider_id_put) | **PUT** /providers/{provider_id} | Update Provider
*SportsApi* | [**create_sport_sports_post**](docs/SportsApi.md#create_sport_sports_post) | **POST** /sports | Create Sport
*SportsApi* | [**delete_sport_sports_sport_id_delete**](docs/SportsApi.md#delete_sport_sports_sport_id_delete) | **DELETE** /sports/{sport_id} | Delete Sport
*SportsApi* | [**get_sport_sports_sport_id_get**](docs/SportsApi.md#get_sport_sports_sport_id_get) | **GET** /sports/{sport_id} | Get Sport
*SportsApi* | [**get_sports_sports_get**](docs/SportsApi.md#get_sports_sports_get) | **GET** /sports | Get Sports
*SportsApi* | [**update_sport_sports_sport_id_put**](docs/SportsApi.md#update_sport_sports_sport_id_put) | **PUT** /sports/{sport_id} | Update Sport


## Documentation For Models

 - [AuthEntityRead](docs/AuthEntityRead.md)
 - [CustomerCreate](docs/CustomerCreate.md)
 - [CustomerPasswordUpdate](docs/CustomerPasswordUpdate.md)
 - [CustomerRead](docs/CustomerRead.md)
 - [CustomerStateEnum](docs/CustomerStateEnum.md)
 - [CustomerUpdate](docs/CustomerUpdate.md)
 - [HTTPValidationError](docs/HTTPValidationError.md)
 - [HealthStatus](docs/HealthStatus.md)
 - [LocationInner](docs/LocationInner.md)
 - [ProviderCreate](docs/ProviderCreate.md)
 - [ProviderMatchBulkItem](docs/ProviderMatchBulkItem.md)
 - [ProviderMatchRead](docs/ProviderMatchRead.md)
 - [ProviderRead](docs/ProviderRead.md)
 - [ProviderUpdate](docs/ProviderUpdate.md)
 - [SportCreate](docs/SportCreate.md)
 - [SportRead](docs/SportRead.md)
 - [SportUpdate](docs/SportUpdate.md)
 - [ValidationError](docs/ValidationError.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="HTTPBearer"></a>
### HTTPBearer

- **Type**: Bearer authentication


## Author




